pygeodesy.trf.TRFXform

Package pygeodesy :: Module trf :: Class TRFXform |
[frames] | no frames]

# Class TRFXform

      object --+
               |
    named._Named --+
                   |
                  TRFXform

A Terrestrial Reference Frame (TRF) converter between two reference frames observed at an `epoch`.

Instance Methods
__init__(self, refName1, refName2, epoch=None, xform=None, rates=None, name='') New TRFXform TRF converter. |
__add__(self, other) |
__eq__(self, other) |
__lt__(self, other) |
__neg__(self) |
__repr__(self) Default `repr(self)`. |
__str__(self) Default `str(self)`. |
__sub__(self, other) |
inverse(self, name='') Return this Xform {inversed}, `refName1` and `-2` swapped. |
rename(self, name='') Change this Xform's name. |
toEpoch(self, epoch) Convert this Xform to `epoch`, if needed. |
toHelmert(self, factor=0.001) Return the Helmert transform from this Xform scaled accordingly. |
toRefFrame(self, point, datum=Datum(name='GRS80', ellipsoid=Ellipsoids.GRS80, transform=Tran`...`, **epoch_epoch2_name) Convert an ellipsoidal point from this Xform's `refName1` and `epoch` to this Xform's `refName2` and `epoch2 or epoch`. |
toRepr(self, **unused) Return the represention of this Xform (`str`). |
toStr(self, epoch=None, **unused) Return this Xform as `"refName1@epochxrefName2"` (`str`). |
toTransform(self, epoch=None, epoch2=None, inverse=False) Combine this Xform observed at `epoch` into a Helmert TransformXform, optionally at `epoch2 or epoch`. |
Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables
| refName2 = `''`
| refName1 = `''`
| xform = `None` hash(x)
| rates = `None` hash(x)

Properties
| epoch Class `property` with a `.name` attribute.
| epoched Get this Xform's aggregate epoch deltas (`float`).
| indirected Is this an indirected Xform? (`str` of space-separated refNames) or `NN`.
| inversed Is this an inversed Xform? (`bool`).
| reframe1 Get the un-/registered from frame (`RefFrame`).
| reframe2 Get the un-/registered to frame (`RefFrame`).
Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, refName1, refName2, epoch=None, xform=None, rates=None, name='') (Constructor) |
New TRFXform TRF converter. Arguments: `refName1` - Source reframe (`str`), converting from. `refName2` - Destination reframe (`str`), converting to. `epoch` - Epoch, a fractional year (Epoch, `scalar` or `str`). `xform` - Transform parameters at `epoch` (TRFXform7Tuple). `rates` - Rate parameters (TRFXform7Tuple), like `xform`, but in `units-per-year`. `name` - Optional name (`str`), overriding the default from method toStr. Raises: `TRFError` - Invalid `refName1`, `refName2` or `epoch`. `TypeError` - Invalid `xform` or `rates`. Overrides: object.__init__ See Also: Functions trfXform, trfTransform0 and trfTransforms.

### __repr__ (self) (Representation operator) |
Default `repr(self)`. Overrides: object.__repr__ (inherited documentation)

### __str__ (self) (Informal representation operator) |
Default `str(self)`. Overrides: object.__str__ (inherited documentation)

### inverse (self, name='') |
Return this Xform {inversed}, `refName1` and `-2` swapped. Returns: The inverse (TRFXform).

### rename (self, name='') |
Change this Xform's name. Arguments: `name` - New name (`str`), overriding the base name `"refName1@epochxrefName2"`. Returns: The old name (`str`). Overrides: named._Named.rename

### toEpoch (self, epoch) |
Convert this Xform to `epoch`, if needed. Arguments: `epoch` - Epoch, fractional year (`Epoch`, `scalar` or `str`). Returns: This Xform or a copy converted to `epoch`. Raises: `TRFError` - Invalid `epoch`.

### toHelmert (self, factor=0.001) |
Return the Helmert transform from this Xform scaled accordingly. Arguments: `factor` - Factor to scale this Xform's `xform` (`scalar`), default from `milli-meter-` to `meter-`, from `milli-arc-` to `arc-seconds` and from `ppB` to `ppM`. Returns: The Helmert transform (TransformXform).

### toRefFrame (self, point, datum=Datum(name='GRS80', ellipsoid=Ellipsoids.GRS80, transform=Tran`...`, **epoch_epoch2_name) |
Convert an ellipsoidal point from this Xform's `refName1` and `epoch` to this Xform's `refName2` and `epoch2 or epoch`. Arguments: `point` - The point to convert (`Cartesian` or `LatLon`). `datum` - Optional datum to define a temporary RefFrame from this Xform's `refName1` or `refName2` (`datum`). `epoch_epoch2_name` - Optional keyword arguments `epoch=None`, `epoch2`=None and `name=refName1`. Returns: A copy of the `point`, converted and renamed. See Also: Method RefFrame.toRefFrame for more details.

### toRepr (self, **unused) |
Return the represention of this Xform (`str`). Overrides: named._Named.toRepr

### toStr (self, epoch=None, **unused) |
Return this Xform as `"refName1@epochxrefName2"` (`str`). Arguments: `epoch` - Epoch (`Epoch`, `scalar` or `str`), overriding this Xform's epoch. Overrides: named._Named.toStr

### toTransform (self, epoch=None, epoch2=None, inverse=False) |
Combine this Xform observed at `epoch` into a Helmert TransformXform, optionally at `epoch2 or epoch`. Arguments: `epoch` - Epoch to observe from (`scalar`), overriding this converter's epoch. `epoch2` - Optional epoch to observe to (`scalar`), overriding `epoch`. `inverse` - Use the Xform's inverse (`bool`). Returns: The Helmert transform (TransformXform). Raises: `TRFError` - Invalid `epoch` or `epoch2`. See Also: Method toHelmert.

Property Details

### epoch Class `property` with a `.name` attribute. Get method: epoch(self) - Get the epoch (Epoch). Set method: epoch(self, epoch) - Set the epoch (Epoch, `scalar` or `str`).

### epoched Get this Xform's aggregate epoch deltas (`float`). Get method: epoched(self) - Get this Xform's aggregate epoch deltas (`float`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### indirected Is this an indirected Xform? (`str` of space-separated refNames) or `NN`. Get method: indirected(self) - Is this an indirected Xform? (`str` of space-separated refNames) or `NN`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### inversed Is this an inversed Xform? (`bool`). Get method: inversed(self) - Is this an inversed Xform? (`bool`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### reframe1 Get the un-/registered from frame (`RefFrame`). Get method: reframe1(self) - Get the un-/registered from frame (`RefFrame`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### reframe2 Get the un-/registered to frame (`RefFrame`). Get method: reframe2(self) - Get the un-/registered to frame (`RefFrame`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.